/*
 * This job renders `data` using nunjucks template `type`
 */

var nunjucks = require('nunjucks');
var fs = require('fs');
var dateFilter = require('nunjucks-date-filter');
var util = require('util');

var MyLoader = nunjucks.Loader.extend({
    fileSystemLoader: {},
    init: function(searchPaths, opts) {
        fileSystemLoader = new nunjucks.FileSystemLoader(searchPaths, opts);
    },

    getSource: function(name) {
        return fileSystemLoader.getSource(name+".nunj");
    }
});

var templates = {};
var env = new nunjucks.Environment(new MyLoader('theme/templates',{watch: require('./config').watch}));

env.addFilter('date', dateFilter);

env.addFilter('paginationList', function(page, count) {
    var curPage = page;
    var pages = [];
    pages.push(curPage);
    for(var i = 0; i < count; i++) {
      curPage = curPage.metadata.prevpage;
      if(curPage === undefined) break;
      pages.unshift(curPage);
    }

    curPage = page;
    for(var i = 0; i < count; i++) {
      curPage = curPage.metadata.nextpage;
      if(curPage === undefined) break;
      pages.push(curPage);
    }
    return pages;
});

env.addFilter('inspect', function(obj) {
    return util.inspect(obj);
});

module.exports = function(data, type) {
  return new Promise(function(resolve, reject) {
    if(templates[type] == undefined) {
      env.getTemplate(type+'.html', true, function(err, tmpl) {
        if(err) reject('Failed to load template '+type+'.html');
        templates[type] = tmpl;
        resolve(tmpl);
      });
    } else {
      resolve(templates[type]);
    }
  }).then(function(tmpl) {
    return tmpl.render(data);
  });
}
